<div align="center">

<img src="images/pixano_logo.png" alt="Pixano" height="100"/>

**Data Centric AI Building Blocks for Computer Vision Application**

[![License](https://img.shields.io/badge/license-CeCILL--C-blue.svg)](LICENSE)
[![GitHub version](https://img.shields.io/github/v/release/pixano/pixano?include_prereleases)](https://github.com/pixano/pixano/releases)
[![PyPI version](https://img.shields.io/pypi/v/pixano)](https://pypi.org/project/pixano/)
[![Python version](https://img.shields.io/badge/python-3.10-important)](https://www.python.org/downloads/)

***Under active development, subject to API change***

</div>


# Installing Pixano

As Pixano requires specific versions for its dependencies, we recommend creating a new Python virtual environment to install it.

For example, with conda:

```shell
conda create -n pixano_env python=3.10
conda activate pixano_env
```

Then, you can install the Pixano package inside that environment with pip:

```shell
pip install pixano
```

# Using the Pixano Explorer

Please refer to [this page](pixano/apps/explorer/README.md) for information on how to use the Pixano Explorer.

# Using the Pixano Annotator

*Coming soon...*

# Contributing

If you find a bug or you think of some missing features that could be useful while using Pixano, please [open an issue](https://github.com/pixano/pixano/issues)!

To contribute more actively to the project, you are welcome to develop the fix or the feature you have in mind, and [create a pull request](https://github.com/pixano/pixano/pulls)!

And if you want to change the application to your liking, feel free to [fork this repository](https://github.com/pixano/pixano/fork)!

# License

Pixano is licensed under the [CeCILL-C license](LICENSE).